
import mcujavasource.mcu.*;
import mcujavasource.mcu.io.*;

/** Tutorial 4: UART repeater.
 * Receives text from a terminal and when Enter is pressed ('\n' char) or 
 * maximum text size is reached, transmits back "You entered ",
 * then the text received.
 * Uart speed = 4800 bps at 1 MHz MCU clock frequency, 38400 bps at 8 MHz.
 * Uart settings: 8 bits character, no parity, one stop bit.
 * Maximum text size is 32 chars.
 */
public class Tutorial4 extends Microcontroller
{
  private static final String HELLO = "Hello from Java!\r\n";
  private static final String BEROFE_TEXT = "You entered '";
  private static final String AFTER_TEXT = "'.\r\n";
  
  private UartInputStream uartInput;
  private UartOutputStream uartOutput;
  
  private byte[] buffer = new byte[32];
  /** Buffer limit */
  private int limit = 0;
  
  public void init()
  { //register initialization on startup
    Uart uart = getHardware().getDefaultUart();
	uart.init(25, true, 8, Uart.Parity.NONE, false);
	uartInput = uart.getInputStream();
	uartOutput = uart.getOutputStream();
  }
  
  public void start()
  { //main program
    getHardware().setInterruptsEnabled(true);
	uartOutput.write(HELLO);
    while(true)
    { limit = 0;
      byte b;
      do
      { b = (byte) uartInput.read();
        buffer[limit++] = b;
      }
      while(b != '\n' && limit < 32);
      uartOutput.write(BEROFE_TEXT);
      int position;
      for(position = 0; position < limit; position++)
      { uartOutput.write(buffer[position]);
      }
      uartOutput.write(AFTER_TEXT);
    }
  }
  
}
